==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/ess/v20201111/models/DescribeThirdPartyAuthCodeRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ess.v20201111.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeThirdPartyAuthCodeRequest extends AbstractModel{

    /**
    * 电子签小程序跳转客户小程序时携带的授权查看码
    */
    @SerializedName("AuthCode")
    @Expose
    private String AuthCode;

    /**
     * Get 电子签小程序跳转客户小程序时携带的授权查看码 
     * @return AuthCode 电子签小程序跳转客户小程序时携带的授权查看码
     */
    public String getAuthCode() {
        return this.AuthCode;
    }

    /**
     * Set 电子签小程序跳转客户小程序时携带的授权查看码
     * @param AuthCode 电子签小程序跳转客户小程序时携带的授权查看码
     */
    public void setAuthCode(String AuthCode) {
        this.AuthCode = AuthCode;
    }

    public DescribeThirdPartyAuthCodeRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeThirdPartyAuthCodeRequest(DescribeThirdPartyAuthCodeRequest source) {
        if (source.AuthCode != null) {
            this.AuthCode = new String(source.AuthCode);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "AuthCode", this.AuthCode);

    }
}

==> tencentcloud-sdk-java-3.1.830-sources.jar: com/tencentcloudapi/ess/v20201111/models/DescribeThirdPartyAuthCodeRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ess.v20201111.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeThirdPartyAuthCodeRequest extends AbstractModel{

    /**
    * 电子签小程序跳转客户小程序时携带的授权查看码
    */
    @SerializedName("AuthCode")
    @Expose
    private String AuthCode;

    /**
    * 操作人信息
    */
    @SerializedName("Operator")
    @Expose
    private UserInfo Operator;

    /**
    * 代理相关应用信息，如集团主企业代子企业操作的场景中ProxyOrganizationId必填
    */
    @SerializedName("Agent")
    @Expose
    private Agent Agent;

    /**
     * Get 电子签小程序跳转客户小程序时携带的授权查看码 
     * @return AuthCode 电子签小程序跳转客户小程序时携带的授权查看码
     */
    public String getAuthCode() {
        return this.AuthCode;
    }

    /**
     * Set 电子签小程序跳转客户小程序时携带的授权查看码
     * @param AuthCode 电子签小程序跳转客户小程序时携带的授权查看码
     */
    public void setAuthCode(String AuthCode) {
        this.AuthCode = AuthCode;
    }

    /**
     * Get 操作人信息 
     * @return Operator 操作人信息
     */
    public UserInfo getOperator() {
        return this.Operator;
    }

    /**
     * Set 操作人信息
     * @param Operator 操作人信息
     */
    public void setOperator(UserInfo Operator) {
        this.Operator = Operator;
    }

    /**
     * Get 代理相关应用信息，如集团主企业代子企业操作的场景中ProxyOrganizationId必填 
     * @return Agent 代理相关应用信息，如集团主企业代子企业操作的场景中ProxyOrganizationId必填
     */
    public Agent getAgent() {
        return this.Agent;
    }

    /**
     * Set 代理相关应用信息，如集团主企业代子企业操作的场景中ProxyOrganizationId必填
     * @param Agent 代理相关应用信息，如集团主企业代子企业操作的场景中ProxyOrganizationId必填
     */
    public void setAgent(Agent Agent) {
        this.Agent = Agent;
    }

    public DescribeThirdPartyAuthCodeRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeThirdPartyAuthCodeRequest(DescribeThirdPartyAuthCodeRequest source) {
        if (source.AuthCode != null) {
            this.AuthCode = new String(source.AuthCode);
        }
        if (source.Operator != null) {
            this.Operator = new UserInfo(source.Operator);
        }
        if (source.Agent != null) {
            this.Agent = new Agent(source.Agent);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "AuthCode", this.AuthCode);
        this.setParamObj(map, prefix + "Operator.", this.Operator);
        this.setParamObj(map, prefix + "Agent.", this.Agent);

    }
}
